require_relative '../spec_helper'
require_relative '../../lib/sastbox-sdk'


RSpec.describe 'Printer' do
  let(:scanner) do
    SastBox::Scanner.new(
      name: 'test_name',
      name_alias: 'test_alias',
      description: 'test_desc',
      support: ['test_support'],
      version: '0.1',
      tool: 'test_tool'
    )
  end

  describe 'print_title' do
    context 'should print with title format' do
      it {expect { scanner.print_title('abc') }.to output("[*] abc\n").to_stdout }
    end
  end

  describe 'print_normal' do
    context 'should print with normal format' do
      it {expect { scanner.print_normal('abc') }.to output("abc\n").to_stdout }
    end
  end

  describe 'print_success' do
    context 'should print with success format' do
      it {expect { scanner.print_success('abc') }.to output("[SUCCESS] abc\n").to_stdout }
    end
  end

  describe 'print_error' do
    context 'should print with error format' do
      it {expect { scanner.print_error('abc') }.to output("[ ERROR ] abc\n").to_stdout }
    end
  end

  describe 'print_with_label' do
    context 'should print with label format' do
      it {expect { scanner.print_with_label('abc', 'def') }.to output("[def] abc\n").to_stdout }
    end
  end

  describe 'print_debug' do
    context 'should print with debug format' do
      it {expect { scanner.print_debug('abc') }.to output(/DEBUG\|.*\| abc/).to_stdout }
    end
  end

  describe 'print_warning' do
    context 'should print with warning format' do
      it {expect { scanner.print_warning('abc') }.to output("[WARNING] abc\n").to_stdout }
    end
  end
end

