require_relative '../spec_helper'
require_relative '../../lib/sastbox-sdk'

require 'json-schema'


RSpec.describe 'Reporter_sarif' do
  let(:scanner) do
    SastBox::Scanner.new(
      name: 'test_name',
      name_alias: 'test_alias',
      description: 'test_desc',
      support: ['test_support'],
      version: '0.1',
      tool: 'test_tool'
    )
  end

  let(:filename) do
    File.absolute_path(File.join(File.dirname(__FILE__), '..', 'samples/low.php'))
  end

  let(:schema) do
    File.absolute_path(File.join(File.dirname(__FILE__), '..', 'samples/sarif-2.1.0-rtm.5.json'))
  end

  let(:snippet) do
    scanner.snippet_read(filename, 10)
  end

  before do
    scanner.parse_opts(['-c', 'xxx'])

    scanner.add_issue(
      title: 'title',
      description: 'description',
      references: [],
      severity: :info,
      filename: filename,
      line: 10,
      cwe_id: -1,
      tags: [],
      snippet: snippet
    )
  end

  describe 'generate_sarif_report' do
    context 'should generate valid SARIF' do
      subject {scanner.generate_sarif_report() }

      it {expect(subject).to be_a(String)}

      it {expect(JSON::Validator.validate(schema, subject)).to be true}
    end
  end
end

