require_relative '../spec_helper'
require_relative '../../lib/sastbox-sdk'

RSpec.describe 'Runner' do
  let(:scanner) do
    SastBox::Scanner.new(
      name: 'test_name',
      name_alias: 'test_alias',
      description: 'test_desc',
      support: ['test_support'],
      version: '0.1',
      tool: 'test_tool'
    )
  end

  let(:scanner_timeout_60_sec) do
    SastBox::Scanner.new(
      name: 'test_name',
      name_alias: 'test_alias',
      description: 'test_desc',
      support: ['test_support'],
      version: '0.1',
      tool: 'test_tool'
    )
  end

  before do
    scanner.parse_opts([])
    scanner_timeout_60_sec.parse_opts(['-t', '1']) # 60 secs

    Thread.report_on_exception = false
  end

  describe '#command?' do
    context 'should return true if binary exists' do
      it { expect(scanner.command?('ls')).to eq true }
    end

    context 'should return false if binary not exists' do
      it { expect(scanner.command?('xxx')).to eq false }
    end
  end

  describe '#run_cmd' do
    context 'should run a valid command and return results' do
      subject { scanner.run_cmd(['uname']) }

      it { expect(subject).to be_an(Array) }
      it { expect(subject.length).to be(2) }
      it { expect(subject[0]).to eq "Linux\n" }
      it { expect(subject[1]).to eq(nil).or be_an(Process::Status) }
    end

    context 'should exit with an invalid command' do
      it do
        expect { scanner.run_cmd(['xxx'])}.to raise_error(SystemExit) do |error|
          expect( error.status ).to eq(1)
        end
      end
      it do
        expect { scanner.run_cmd(['xxx'])}.to raise_error(SystemExit) do |error|
          expect( error.message ).to eq('exit')
        end
      end
    end
  end

  describe '#run_cmd_with_timeout' do
    context 'should not fail when not exceeded timeout' do
      subject { scanner_timeout_60_sec.run_cmd_with_timeout(['uname']) }

      it { expect(subject).to be_an(Array) }
      it { expect(subject.length).to be(2) }
      it { expect(subject[0]).to eq "Linux\n" }
      it { expect(subject[1]).to eq(nil).or be_an(Process::Status) }
    end

    context 'should fail when exceeded timeout' do
      it do
        expect { scanner_timeout_60_sec.run_cmd_with_timeout(['sleep', '70'])}.to raise_error(SystemExit) do |error|
          expect( error.status ).to eq(1)
        end
      end
      it do
        expect { scanner_timeout_60_sec.run_cmd_with_timeout(['sleep', '70'])}.to raise_error(SystemExit) do |error|
          expect( error.message ).to eq('exit')
        end
      end
    end
  end
end

