require_relative '../spec_helper'
require_relative '../../lib/sastbox-sdk'


RSpec.describe 'SeverityCalculator' do
  let(:scanner) do
    SastBox::Scanner.new(
      name: 'test_name',
      name_alias: 'test_alias',
      description: 'test_desc',
      support: ['test_support'],
      version: '0.1',
      tool: 'test_tool'
    )
  end

  describe 'add_severity' do
    context 'when dont have severity field' do
      let(:issue) do
        {
          title: 'cmd exec',
          description: 'cmd exec'
        }
      end

      before do
        scanner.add_severity(issue)
      end

      it {expect( issue[:severity]).to eq :critical}
    end

    context 'when have severity field different from accepted levels' do
      let(:issue) do
        {
          title: 'cmd exec',
          description: 'cmd exec',
          severity: 'anything'
        }
      end

      before do
        scanner.add_severity(issue)
      end

      it {expect( issue[:severity]).to eq :critical}
    end

    context 'when have valid severity field' do
      let(:issue) do
        {
          title: 'anything',
          description: 'anything',
          severity: :info
        }
      end

      before do
        scanner.add_severity(issue)
      end

      it {expect( issue[:severity]).to eq :info}
    end
  end


  describe 'attempt_to_determine_severity' do
    context 'when critical' do
      let(:issue) do
        {
          title: 'cmd exec',
          description: 'cmd exec'
        }
      end

      it {expect( scanner.attempt_to_determine_severity(issue)).to eq :critical}
    end

    context 'when high' do
      let(:issue) do
        {
          title: 'xss',
          description: 'xss'
        }
      end

      it {expect( scanner.attempt_to_determine_severity(issue)).to eq :high}
    end

    context 'when medium' do
      let(:issue) do
        {
          title: 'csrf',
          description: 'csrf'
        }
      end

      it {expect( scanner.attempt_to_determine_severity(issue)).to eq :medium}
    end

    context 'when low' do
      let(:issue) do
        {
          title: 'logging',
          description: 'logging'
        }
      end

      it {expect( scanner.attempt_to_determine_severity(issue)).to eq :low}
    end

    context 'when undefined' do
      let(:issue) do
        {
          title: 'anything',
          description: 'anything'
        }
      end

      it {expect( scanner.attempt_to_determine_severity(issue)).to eq :undefined}
    end
  end


end

